Jep 3.0 Release Notes
*********************
This release emphasized building with Python's distutils and using a
Python import hook for importing Java classes.  It is compatible with
Python 2.6 and 2.7.


distutils support
~~~~~~~~~~~~~~~~~
Jep now supports building, installing, and testing using Python's distutils for
simplified building and installation.  Use setup.py to build and install with
distutils.

https://docs.python.org/2/distutils/


Python import hook
~~~~~~~~~~~~~~~~~~
Jep now uses a Python importer hook, PEP 302, for handling imports of Java
packages and classes and Python packages and modules.

https://www.python.org/dev/peps/pep-0302/


jep command line script
~~~~~~~~~~~~~~~~~~~~~~~
Jep now includes a script for running a Jep interpreter from the command line
similar to running a Python interpreter from the command line.  The Jep
interpreter has access to Java classes on the classpath.


Implemented rich compare on PyJObject
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
PyJObject now implements Python's rich compare by delegating to the Java
object's equals(Object) method.

https://www.python.org/dev/peps/pep-0207/

